@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 
 
-#nice apt-get -s -o Debug::NoLocking=true upgrade | grep ^Inst 
+# nice apt-get -s -o Debug::NoLocking=true upgrade | grep ^Inst
 
 import apt
 import apt_pkg
@@ -22,20 +22,20 @@ def _(msg):
 
 
 def _handleException(type, value, tb):
-    sys.stderr.write("E: "+ _("Unknown Error: '%s' (%s)") % (type,value))
+    sys.stderr.write("E: " + _("Unknown Error: '%s' (%s)") % (type, value))
     sys.exit(-1)
 
 
 def clean(cache, depcache):
     " unmark (clean) all changes from the given depcache "
     # mvo: looping is too inefficient with the new auto-mark code
-    #for pkg in cache.Packages:
-    #    depcache.MarkKeep(pkg)
+    # for pkg in cache.Packages:
+    #     depcache.MarkKeep(pkg)
     depcache.init()
 
 
 def saveDistUpgrade(cache, depcache):
-    """ this functions mimics a upgrade but will never remove anything """
+    """ this function mimics a upgrade but will never remove anything """
     depcache.upgrade(True)
     if depcache.del_count > 0:
         clean(cache, depcache)
@@ -57,21 +57,21 @@ def isSecurityUpgrade(ver):
 def write_package_names(outstream, cache, depcache):
     " write out package names that change to outstream "
     pkgs = [pkg for pkg in cache.packages if depcache.marked_install(pkg) or
-        depcache.marked_upgrade(pkg)]
+            depcache.marked_upgrade(pkg)]
     outstream.write("\n".join([p.name for p in pkgs]))
 
 
 def write_human_readable_summary(outstream, upgrades, security_updates):
     " write out human summary summary to outstream "
     outstream.write(gettext.dngettext("update-notifier",
-                            "%i package can be updated.",
-                            "%i packages can be updated.",
-                            upgrades) % upgrades)
+                                      "%i package can be updated.",
+                                      "%i packages can be updated.",
+                                      upgrades) % upgrades)
     outstream.write("\n")
     outstream.write(gettext.dngettext("update-notifier",
-                            "%i update is a security update.",
-                            "%i updates are security updates.",
-                            security_updates)  % security_updates)
+                                      "%i update is a security update.",
+                                      "%i updates are security updates.",
+                                      security_updates) % security_updates)
     outstream.write("\n")
 
 
@@ -81,20 +81,21 @@ def init():
     os.nice(19)
     apt_pkg.init()
 
+
 def run(options=None):
 
     # we are run in "are security updates installed automatically?"
     # question mode
     if options.security_updates_unattended:
         res = apt_pkg.config.find_i("APT::Periodic::Unattended-Upgrade", 0)
-        #print(res)
+        # print(res)
         sys.exit(res)
 
     # get caches
     try:
         cache = apt_pkg.Cache(apt.progress.base.OpProgress())
     except SystemError as e:
-        sys.stderr.write("E: "+ _("Error: Opening the cache (%s)") % e)
+        sys.stderr.write("E: " + _("Error: Opening the cache (%s)") % e)
         sys.exit(-1)
     depcache = apt_pkg.DepCache(cache)
 
@@ -104,14 +105,14 @@ def run(options=None):
         depcache.init()
 
     if depcache.broken_count > 0:
-        sys.stderr.write("E: "+ _("Error: BrokenCount > 0"))
+        sys.stderr.write("E: " + _("Error: BrokenCount > 0"))
         sys.exit(-1)
 
     # do the upgrade (not dist-upgrade!)
     try:
-        saveDistUpgrade(cache,depcache)
+        saveDistUpgrade(cache, depcache)
     except SystemError as e:
-        sys.stderr.write("E: "+ _("Error: Marking the upgrade (%s)") % e)
+        sys.stderr.write("E: " + _("Error: Marking the upgrade (%s)") % e)
         sys.exit(-1)
 
     # analyze the ugprade
@@ -122,7 +123,8 @@ def run(options=None):
     with apt.Cache() as aptcache:
         for pkg in cache.packages:
             # skip packages that are not marked upgraded/installed
-            if not (depcache.marked_install(pkg) or depcache.marked_upgrade(pkg)):
+            if not (depcache.marked_install(pkg) or
+                    depcache.marked_upgrade(pkg)):
                 continue
             # check if this is really a upgrade or a false positive
             # (workaround for ubuntu #7907)
@@ -140,7 +142,8 @@ def run(options=None):
             try:
                 from UpdateManager.Core.UpdateList import UpdateList
                 ul = UpdateList(None)
-                ignored = ul._is_ignored_phased_update(aptcache[pkg.name])
+                ignored = ul._is_ignored_phased_update(
+                    aptcache[pkg.get_fullname()])
                 if ignored:
                     depcache.mark_keep(pkg)
                     continue
@@ -150,10 +153,12 @@ def run(options=None):
             upgrades = upgrades + 1
 
             # now check for security updates that are masked by a
-            # canidate version from another repo (-proposed or -updates)
+            # candidate version from another repo (-proposed or -updates)
             for ver in pkg.version_list:
-                if (inst_ver and apt_pkg.version_compare(ver.ver_str, inst_ver.ver_str) <= 0):
-                    #print("skipping '%s' " % ver.VerStr)
+                if (inst_ver and apt_pkg.version_compare(ver.ver_str,
+                                                         inst_ver.ver_str) <=
+                        0):
+                    # print("skipping '%s' " % ver.VerStr)
                     continue
                 if isSecurityUpgrade(ver):
                     security_updates += 1
@@ -179,8 +184,8 @@ if __name__ == "__main__":
     sys.excepthook = _handleException
 
     # gettext
-    APP="update-notifier"
-    DIR="/usr/share/locale"
+    APP = "update-notifier"
+    DIR = "/usr/share/locale"
     gettext.bindtextdomain(APP, DIR)
     gettext.textdomain(APP)
 
@@ -190,7 +195,8 @@ if __name__ == "__main__":
                       "--package-names",
                       action="store_true",
                       dest="show_package_names",
-                      help=_("Show the packages that are going to be installed/upgraded"))
+                      help=_("Show the packages that are "
+                             "going to be installed/upgraded"))
     parser.add_option("",
                       "--human-readable",
                       action="store_true",
