@@ -222,7 +222,10 @@ def process_download_requests():
             if not isinstance(e, OSError):
                 traceback.print_exc(file=sys.stderr)
 
-        print("%s: processing..." % (relfile))
+        try:
+            print("%s: processing..." % (relfile))
+        except OSError:
+            pass
         hook = debian.deb822.Deb822()
         files = []
         sums = []
@@ -240,7 +243,7 @@ def process_download_requests():
                         if should == "false":
                             # Do nothing with this file.
                             break
-                    except:
+                    except (DebconfError, KeyError):
                         pass
                     finally:
                         db.shutdown()
@@ -249,7 +252,10 @@ def process_download_requests():
                 try:
                     downloaded = set()
                     for i in range(len(files)):
-                        print("%s: downloading %s" % (relfile, files[i]))
+                        try:
+                            print("%s: downloading %s" % (relfile, files[i]))
+                        except OSError:
+                            pass
                         dest_file = download_file(files[i], sums[i])
                         if dest_file:
                             command.append(dest_file)
