@@ -201,6 +201,14 @@ avahi_disabled()
         g_spawn_async (NULL, argv, NULL, G_SPAWN_DO_NOT_REAP_CHILD, NULL, NULL, NULL, NULL);
 }
 
+void livepatch_check()
+{
+        g_debug("livepatch_check ()");
+        gchar *argv[2];
+        argv[0] = "/usr/lib/update-notifier/livepatch-notification";
+        argv[1] = NULL;
+        g_spawn_async (NULL, argv, NULL, G_SPAWN_DO_NOT_REAP_CHILD, NULL, NULL, NULL, NULL);
+}
 
 static gboolean
 trayapplet_create (TrayApplet *ta, UpgradeNotifier *un, char *name)
@@ -269,6 +277,10 @@ monitor_cb(GFileMonitor *handle,
       g_debug_inotify("avahi disabled due to unicast .local domain");
       un->unicast_local_avahi_pending = TRUE;
    }
+   if(strstr(info_uri, LIVEPATCH_FILE)) {
+      g_debug_inotify("livepatch status changed");
+      un->livepatch_pending = TRUE;
+   }
 }
 
 /*
@@ -280,6 +292,7 @@ monitor_cb(GFileMonitor *handle,
  * - hook_pending: we have new upgrade hook information
  * - crashreport_pending: we have a new crashreport
  * - unicast_local_avahi_pending: avahi got disabled due to a unicast .local domain
+ * - livepatch_pending: livepatch status changed
  *
  */
 static gboolean
@@ -364,6 +377,12 @@ file_monitor_periodic_check(gpointer data)
       un->unicast_local_avahi_pending = FALSE;
    }
 
+  if(un->livepatch_pending) {
+      g_debug("checking for livepatch status now");
+      livepatch_check ();
+      un->livepatch_pending = FALSE;
+   } 
+
    // reset the bitfields (for the next "time-slice")
    un->dpkg_was_run = FALSE;
    un->apt_get_running = FALSE;
@@ -407,6 +426,7 @@ monitor_init(UpgradeNotifier *un)
       "/var/lib/update-notifier/dpkg-run-stamp",
       "/var/lib/apt/periodic/update-success-stamp",
       UNICAST_LOCAL_AVAHI_FILE,
+      LIVEPATCH_FILE,
       NULL};
    for(i=0;monitor_files[i] != NULL;i++) {
       if (getenv("UPSTART_SESSION") && monitor_files[i] == UNICAST_LOCAL_AVAHI_FILE) {
